#!/bin/bash

#
## Mise en place complet d'un annuaire ldap à partir d'un ldif##
# last update 03/2020 
# Distribué selon la licence GPL
# franck.molle@sambaedu.org


#Couleurs
COLTITRE="\033[1;35m"   # Rose
COLPARTIE="\033[1;34m"  # Bleu

COLTXT="\033[0;37m"     # Gris
COLCHOIX="\033[1;33m"   # Jaune
COLDEFAUT="\033[0;33m"  # Brun-jaune
COLSAISIE="\033[1;32m"  # Vert

COLCMD="\033[1;37m"     # Blanc

COLERREUR="\033[1;31m"  # Rouge
COLINFO="\033[0;36m"    # Cyan



if [ "$1" = "--help" -o "$1" = "-h" -o "$1" = "" ]
then
	echo "Met en place la tructure complète d'un annuaire LDAP à partir d'un export ldif"
	echo "Usage : $0 fichier_export.ldif "
	echo "-h Cette aide"
	exit
fi	
. /usr/share/se3/includes/config.inc.sh -lm
. /usr/share/se3/includes/functions.inc.sh 


PEOPLER=`echo $peopleRdn |cut -d = -f 2`
RIGHTSR=`echo $rightsRdn |cut -d = -f 2`
GROUPSR=`echo $groupsRdn |cut -d = -f 2`

SVG="$1"

ERREUR()
{
        echo -e "$COLERREUR"
        echo "ERREUR!"
        echo -e "$1"
        echo -e "$COLTXT"
        exit 0
}

POURSUIVRE()
{
        REPONSE=""
        while [ "$REPONSE" != "o" -a "$REPONSE" != "n" ]
        do
                echo -e "$COLTXT"
                echo -e "Peut-on poursuivre? (${COLCHOIX}o/n${COLTXT}) $COLSAISIE\c"
                read REPONSE
        done

        if [ "$REPONSE" != "o" ]; then
                ERREUR "Abandon!"
        fi
}

POURSUIVRE_OU_CORRIGER()
{
	REPONSE=""
	while [ "$REPONSE" != "1" -a "$REPONSE" != "2" ]
	do
		if [ ! -z "$1" ]; then
			echo -e "$COLTXT\c"
			echo -e "Peut-on poursuivre (${COLCHOIX}1${COLTXT}) ou voulez-vous corriger (${COLCHOIX}2${COLTXT}) ? [${COLDEFAUT}${1}${COLTXT}] $COLSAISIE\c"
			read REPONSE

			if [ -z "$REPONSE" ]; then
				REPONSE="$1"
			fi
		else
			echo -e "$COLTXT\c"
			echo -e "Peut-on poursuivre (${COLCHOIX}1${COLTXT}) ou voulez-vous corriger (${COLCHOIX}2${COLTXT}) ? $COLSAISIE\c"
			read REPONSE
		fi
	done
}

echo "Attention l'annuaire actuel et sa structure seront remplacés par le contenu de l'export fourni"
POURSUIVRE


dossier=/var/se3/save/ldap
mkdir -p ${dossier}

ladate=$(date "+%Y%m%d.%H%M%S")

# Sauvegarde préalable
echo -e "$COLTXT"
echo "Sauvegarde préalable de l'annuaire dans son état actuel..."
echo -e "$COLCMD\c"
ldapsearch -xLLL -D "$adminRdn,$ldap_base_dn" -w $adminPw -o ldif-wrap=no > $dossier/svg_${ladate}.ldif

echo -e "$COLTXT"

echo "Recherche de la base dn dans le fichier ldif fourni"


BASEDN_LDIF="$(perl -p0e 's/\n //g' $SVG | grep '^dn:' | head -n1 | awk '{print $2}')"

SAMBADOMAIN=$(grep "^sambaDomainName" $SVG | awk '{print $2}')
SAMBASID=$(grep "^sambaSID" $SVG |  grep -v "S-1-5-32-546" | sort | head -n1 | awk '{print $2}')

REPONSE=""
while [ "$REPONSE" != "1" ]
do
	echo -e "base trouvée : $COLINFO$BASEDN_LDIF$COLTXT"
	echo -e "${COLTXT}Utiliser cette base dn ? (entree pour confirmer) ou saisissez votre choix: $COLSAISIE\c"
	read -e BASEDN_SAISIE

	if [ -z "$BASEDN_SAISIE" ]; then
		BASEDN_SAISIE="$BASEDN_LDIF"
	fi
		echo -e "$COLTXT"
		echo "Vous avez choisi:"
		echo -e "La base dn suivante ${COLINFO}$BASEDN_SAISIE${COLTXT}"
		POURSUIVRE_OU_CORRIGER
done

echo
echo -e "$COLPARTIE Résumé des modifications :
$COLTXT- Analyse de${COLINFO} $1 
$COLTXT- Mise en place la base dn${COLINFO}  $BASEDN_SAISIE
$COLTXT- Vidage de l'annuaire insertion du contenu de${COLINFO}  $1
$COLTXT- Sid samba positionné à${COLINFO}  $SAMBASID
$COLTXT- Nom de domaine Samba récupéré ${COLINFO}  $SAMBADOMAIN"

	echo -e "$COLTXT"
POURSUIVRE

echo -e "$COLTXT"
echo "changement de la basedn dans mysql"
CHANGEMYSQL ldap_base_dn $BASEDN_SAISIE

echo -e "$COLTXT"
echo "changement du sambaSID dans mysql"
CHANGEMYSQL domainsid $SAMBASID

echo -e "$COLTXT"
echo "changement du nom de domaine samba dans mysql"
CHANGEMYSQL se3_domain $SAMBADOMAIN


/usr/share/se3/scripts/refresh_cache_params.sh
ldap_base_dn="$BASEDN_SAISIE"
domainsid="$SAMBASID"
se3_domain="$SAMBADOMAIN"


# service slapd stop
# sleep 2
# service samba stop
# sleep 1
# On sauvegarde DB_CONFIG
if [ -e "/var/lib/ldap/DB_CONFIG" ]
then
	cp /var/lib/ldap/DB_CONFIG /var/se3/save/ldap/
else
	cp /var/se3/save/ldap/DB_CONFIG /var/lib/ldap/
fi

echo -e "$COLCMD\c"
service slapd stop
sleep 1

echo -e "$COLTXT"
echo "Reconstruction de la configuration ldap"
echo -e "$COLCMD\c"
/usr/share/se3/scripts/mkSlapdConf.sh installinit

echo -e "$COLTXT"
echo "Supression de /var/lib/ldap"
rm -rf /var/lib/ldap/*

cp  /var/se3/save/ldap/DB_CONFIG /var/lib/ldap/

echo "Intégration du fichier ldif  $1"
echo -e "$COLCMD\c"
slapadd -c -l $SVG

chown openldap:openldap /var/lib/ldap/*

if [ "$?" = "0" ]; then
	echo -e "$COLTXT"
	echo "La commande a semble-t-il réussi."
	# Droits sur /var/lib/ldap
	chown -R openldap.openldap /var/lib/ldap
	echo -e "$COLTXT"
	echo -e "Redémarrage du serveur d'annuaire LDAP"
	echo -e "$COLCMD\c"
	/etc/init.d/slapd start
	test=$(ps aux | grep slapd | grep -v grep)
	if [ -z "$test" ]; then
		echo -e "$COLERREUR"
		echo "Le redémarrage du service slapd a échoué."

		echo -e "$COLTXT"
		echo "Vous devrez redémarrer manuellement le service par:"
		echo -e "$COLCMD\c"
		echo "   /etc/init.d/slapd start"
	else
		echo -e "$COLTXT"
		echo "Rédémarrage du service slapd réussi."
	fi
fi

echo -e "$COLTXT"
echo "changement du SID pour samba"
net setlocalsid $SAMBASID

# echo "Start service samba"
# service samba start
# sleep 2
echo -e "$COLTXT"
echo "lancement update-smbconf.sh pour conf initiale"

echo -e "$COLCMD\c"
update-smbconf.sh 
echo -e "$COLINFO"
echo "Nota : Il est normal que le mode ldap trusted ne soit pas activé à cette étape" 
sleep 2

echo -e "$COLTXT"
echo "remise en place pass ldap samba"
smbpasswd -w $(cat /etc/ldap.secret)


echo -e "$COLCMD\c"
service samba stop
sleep 2
rm -f /var/lib/samba/*.tdb
service samba start
echo -e "$COLTXT"
/usr/share/se3/sbin/create_adminse3.sh

echo -e "$COLTXT"
echo "Lancement correctSID.sh au cas ou"
echo -e "$COLCMD\c"
correctSID.sh 
echo -e "$COLTXT"

echo "lancement update-smbconf.sh pour activation ldaptrusted"
echo -e "$COLCMD\c"
update-smbconf.sh 

ETAT_LDAP_TRUSTED="$(grep "ldapsam:trusted = Yes" /etc/samba/smb.conf)"
if [ -n "$ETAT_LDAP_TRUSTED" ];then 
	echo -e "$COLINFO"
	echo "ldaptrusted activé avec succès !"
else
	echo -e "$COLERREUR"
	echo "Le mode ldap trusted n'a pu être activé :/"
fi

echo -e "$COLTXT"
sleep 3

if [ -e "/usr/share/se3/sbin/corrige_ldap_smb44.sh" -a -z "$ETAT_LDAP_TRUSTED" ]; then
	echo -e "$COLTXT"
	echo "Mise en conformité de l'annuaire à la norme samba 4.4"
	echo "/usr/share/se3/sbin/corrige_ldap_smb44.sh"
	sleep 2
	echo -e "$COLCMD\c"
 	/usr/share/se3/sbin/corrige_ldap_smb44.sh
fi

echo -e $COLTITRE
echo "Terminé !!"
echo -e "$COLTXT"

echo "Pour information"
echo "Nombre d'utilisateurs dans l'annuaire :  $(ldapsearch -xLLL -b $peopleRdn,$ldap_base_dn uid | grep ^uid | wc -l)"
echo "Nombre de machines : $(ldapsearch -xLLL -b $computersRdn,$ldap_base_dn cn=* cn | grep "cn:" | grep -v "\$$" | wc -l)"
echo "pour tester la connexion samba : 
smbclient -L localhost -U adminse3 puis saisir le pass adminse3 actuel : $xppass"

exit 0






